
1.0a4 (2016-02-05)
------------------

- Use 'migrate' instead of 'syncdb' for Django > 1.7.x.
  [timo]


1.0a3 (2015-09-28)
------------------

- Add list_classifiers to setup.py.
  [timo]

- Fix user creation and startup. This fixes #3.
  [MatthewWilkes]


1.0a2 (2015-06-25)
------------------

- Remove Django and zest.releaser from requirements.txt. This fixes #2.
  [timo]


1.0a1 (2015-06-24)
------------------

- Initial release.
  [timo]
